
.. If you created a package, create one automodule per module in the package.

.. automodule:: adafruit_thermal_printer.thermal_printer
   :members:

.. automodule:: adafruit_thermal_printer.thermal_printer_264
   :members:

.. automodule:: adafruit_thermal_printer.thermal_printer_legacy
   :members:
